<?xml version="1.0" encoding="UTF-8"?>
<rss xmlns:content="http://purl.org/rss/1.0/modules/content/" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:taxo="http://purl.org/rss/1.0/modules/taxonomy/" version="2.0">
  <channel>
    <title>topic Hi Robert, in OpenCL* for CPU</title>
    <link>https://community.intel.com/t5/OpenCL-for-CPU/Memcpy-performance-using-opencl-kernel/m-p/1019705#M3237</link>
    <description>&lt;P&gt;Hi Robert,&lt;/P&gt;

&lt;P&gt;I am using below configuration and code:&lt;/P&gt;

&lt;P&gt;1. What is your OS?&amp;nbsp; Windows 7 64 bit&lt;/P&gt;

&lt;P&gt;2. What is the processor you are working on?&amp;nbsp; i7 4770 CPU @3.4 GHz&lt;/P&gt;

&lt;P&gt;3. Which version of the graphics driver do you use? 10.18.14.4222&lt;/P&gt;

&lt;P&gt;4. What is the global size for your kernel? 1920x1080&lt;/P&gt;

&lt;P&gt;5. What, if any, is your local size? I have set it to NULL&lt;/P&gt;

&lt;P&gt;6. What is the version of the Vtune that you are using? Vtune 2015 update 2&lt;/P&gt;

&lt;P&gt;Here are the parts of the code which I am using to run this kernel:&lt;/P&gt;

&lt;P&gt;/*Setting the params */&lt;/P&gt;

&lt;P&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp; img_fmt.image_channel_order = CL_R;&lt;BR /&gt;
	&amp;nbsp;&amp;nbsp; &amp;nbsp;img_fmt.image_channel_data_type = CL_UNSIGNED_INT8;&lt;/P&gt;

&lt;P&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp; p-&amp;gt;origin[0] = 0;&amp;nbsp; //width of image&lt;BR /&gt;
	&amp;nbsp;&amp;nbsp;&amp;nbsp; p-&amp;gt;origin[1] = 0;&amp;nbsp; //height of image&lt;BR /&gt;
	&amp;nbsp;&amp;nbsp;&amp;nbsp; p-&amp;gt;origin[2] = 0;&amp;nbsp; //req for 3D image&lt;/P&gt;

&lt;P&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp; p-&amp;gt;region[0] = width;&lt;BR /&gt;
	&amp;nbsp;&amp;nbsp;&amp;nbsp; p-&amp;gt;region[1] = height;&lt;BR /&gt;
	&amp;nbsp;&amp;nbsp;&amp;nbsp; p-&amp;gt;region[2] = 1;&amp;nbsp; // For a 2D image this is set to 1&lt;/P&gt;

&lt;P&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp; p-&amp;gt;global_ws[0][0] = width;&lt;BR /&gt;
	&amp;nbsp;&amp;nbsp;&amp;nbsp; p-&amp;gt;global_ws[0][1] = (height);&lt;/P&gt;

&lt;P&gt;&amp;nbsp; /* ingest frame to global memory on the device: */&amp;nbsp;&amp;nbsp; &amp;nbsp;&lt;BR /&gt;
	&amp;nbsp; ret = clEnqueueWriteImage(p-&amp;gt;command_queue, p-&amp;gt;memobj_in_luma, CL_FALSE, p-&amp;gt;origin, \&lt;BR /&gt;
	&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp; p-&amp;gt;region,0,0,(void *) in,&amp;nbsp; 0, NULL, &amp;amp;evt[0]);&lt;/P&gt;

&lt;P&gt;/*enqueue the kernel*/&lt;BR /&gt;
	&amp;nbsp; ret = clEnqueueNDRangeKernel(p-&amp;gt;command_queue, p-&amp;gt;deint_kernel_y, 2, 0, \&lt;BR /&gt;
	&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp; p-&amp;gt;global_ws[0], NULL, 1, &amp;amp;evt[0], &amp;amp;evt[3]);&lt;/P&gt;

&lt;P&gt;/* Read back from device*/&lt;/P&gt;

&lt;P&gt;&amp;nbsp; ret = clEnqueueReadImage(p-&amp;gt;command_queue, p-&amp;gt;memobj_out_luma, CL_FALSE, \&lt;BR /&gt;
	&amp;nbsp;&amp;nbsp;&amp;nbsp; p-&amp;gt;origin,p-&amp;gt;region,0, 0,(void *)(out),0, 0, 0);&lt;/P&gt;

&lt;P&gt;/* KERNEL CODE */&lt;/P&gt;

&lt;PRE&gt;__kernel void deinterlace_Y(__read_only image2d_t YIn, __write_only image2d_t YOut)
{

/* Doing operation of Memcpy */

int2 coord_src = (int2)(get_global_id(0), get_global_id(1));

const sampler_t smp = CLK_FILTER_NEAREST | CLK_NORMALIZED_COORDS_FALSE | CLK_ADDRESS_CLAMP_TO_EDGE;

uint4 pixel4 = read_imageui(YIn, smp, coord_src);

write_imageui(YOut, coord_src, pixel4);
&lt;/PRE&gt;

&lt;P&gt;}&lt;/P&gt;

&lt;P&gt;&amp;nbsp;&lt;/P&gt;</description>
    <pubDate>Thu, 23 Jul 2015 06:05:09 GMT</pubDate>
    <dc:creator>Manish_K_</dc:creator>
    <dc:date>2015-07-23T06:05:09Z</dc:date>
    <item>
      <title>Memcpy performance using opencl kernel</title>
      <link>https://community.intel.com/t5/OpenCL-for-CPU/Memcpy-performance-using-opencl-kernel/m-p/1019702#M3234</link>
      <description>&lt;P style="margin: 0px 0px 1em; padding: 0px; border: 0px; font-size: 15px; clear: both; color: rgb(34, 34, 34); font-family: 'Helvetica Neue', Helvetica, Arial, sans-serif; font-style: normal; font-variant: normal; font-weight: normal; letter-spacing: normal; line-height: 17.7272720336914px; orphans: auto; text-align: left; text-indent: 0px; text-transform: none; white-space: normal; widows: 1; word-spacing: 0px; -webkit-text-stroke-width: 0px; background-color: rgb(255, 255, 255);"&gt;Hi,&lt;/P&gt;

&lt;P style="margin: 0px 0px 1em; padding: 0px; border: 0px; font-size: 15px; clear: both; color: rgb(34, 34, 34); font-family: 'Helvetica Neue', Helvetica, Arial, sans-serif; font-style: normal; font-variant: normal; font-weight: normal; letter-spacing: normal; line-height: 17.7272720336914px; orphans: auto; text-align: left; text-indent: 0px; text-transform: none; white-space: normal; widows: 1; word-spacing: 0px; -webkit-text-stroke-width: 0px; background-color: rgb(255, 255, 255);"&gt;I have written a simple memcpy kernel as written below:&lt;/P&gt;

&lt;P style="margin: 0px 0px 1em; padding: 0px; border: 0px; font-size: 15px; clear: both; color: rgb(34, 34, 34); font-family: 'Helvetica Neue', Helvetica, Arial, sans-serif; font-style: normal; font-variant: normal; font-weight: normal; letter-spacing: normal; line-height: 17.7272720336914px; orphans: auto; text-align: left; text-indent: 0px; text-transform: none; white-space: normal; widows: 1; word-spacing: 0px; -webkit-text-stroke-width: 0px; background-color: rgb(255, 255, 255);"&gt;I am analyzing its performance on GPU using vtune.&lt;/P&gt;

&lt;PRE style="margin: 0px 0px 1em; padding: 5px; border: 0px; font-size: 13px; overflow: auto; width: auto; max-height: 600px; font-family: Consolas, Menlo, Monaco, 'Lucida Console', 'Liberation Mono', 'DejaVu Sans Mono', 'Bitstream Vera Sans Mono', 'Courier New', monospace, sans-serif; word-wrap: normal; color: rgb(34, 34, 34); font-style: normal; font-variant: normal; font-weight: normal; letter-spacing: normal; orphans: auto; text-align: left; text-indent: 0px; text-transform: none; widows: 1; word-spacing: 0px; -webkit-text-stroke-width: 0px; background-color: rgb(238, 238, 238);"&gt;&lt;CODE style="margin: 0px; padding: 0px; border: 0px; font-size: 13px; font-family: Consolas, Menlo, Monaco, 'Lucida Console', 'Liberation Mono', 'DejaVu Sans Mono', 'Bitstream Vera Sans Mono', 'Courier New', monospace, sans-serif; white-space: inherit; background-color: rgb(238, 238, 238);"&gt;__kernel void deinterlace_Y(__read_only image2d_t YIn, __write_only image2d_t YOut)
{

/* Doing operation of Memcpy */

int2 coord_src = (int2)(get_global_id(0), get_global_id(1));

const sampler_t smp = CLK_FILTER_NEAREST | CLK_NORMALIZED_COORDS_FALSE | CLK_ADDRESS_CLAMP_TO_EDGE;

uint4 pixel4 = read_imageui(YIn, smp, coord_src);

write_imageui(YOut, coord_src, pixel4);
&lt;/CODE&gt;&lt;/PRE&gt;

&lt;P style="margin: 0px 0px 1em; padding: 0px; border: 0px; font-size: 15px; clear: both; color: rgb(34, 34, 34); font-family: 'Helvetica Neue', Helvetica, Arial, sans-serif; font-style: normal; font-variant: normal; font-weight: normal; letter-spacing: normal; line-height: 17.7272720336914px; orphans: auto; text-align: left; text-indent: 0px; text-transform: none; white-space: normal; widows: 1; word-spacing: 0px; -webkit-text-stroke-width: 0px; background-color: rgb(255, 255, 255);"&gt;}&lt;/P&gt;

&lt;P style="margin: 0px 0px 1em; padding: 0px; border: 0px; font-size: 15px; clear: both; color: rgb(34, 34, 34); font-family: 'Helvetica Neue', Helvetica, Arial, sans-serif; font-style: normal; font-variant: normal; font-weight: normal; letter-spacing: normal; line-height: 17.7272720336914px; orphans: auto; text-align: left; text-indent: 0px; text-transform: none; white-space: normal; widows: 1; word-spacing: 0px; -webkit-text-stroke-width: 0px; background-color: rgb(255, 255, 255);"&gt;I observe the below stats for Execution units:&lt;/P&gt;

&lt;PRE style="margin: 0px 0px 1em; padding: 5px; border: 0px; font-size: 13px; overflow: auto; width: auto; max-height: 600px; font-family: Consolas, Menlo, Monaco, 'Lucida Console', 'Liberation Mono', 'DejaVu Sans Mono', 'Bitstream Vera Sans Mono', 'Courier New', monospace, sans-serif; word-wrap: normal; color: rgb(34, 34, 34); font-style: normal; font-variant: normal; font-weight: normal; letter-spacing: normal; orphans: auto; text-align: left; text-indent: 0px; text-transform: none; widows: 1; word-spacing: 0px; -webkit-text-stroke-width: 0px; background-color: rgb(238, 238, 238);"&gt;&lt;CODE style="margin: 0px; padding: 0px; border: 0px; font-size: 13px; font-family: Consolas, Menlo, Monaco, 'Lucida Console', 'Liberation Mono', 'DejaVu Sans Mono', 'Bitstream Vera Sans Mono', 'Courier New', monospace, sans-serif; white-space: inherit; background-color: rgb(238, 238, 238);"&gt;    EU Array
&lt;/CODE&gt;&lt;/PRE&gt;

&lt;P style="margin: 0px 0px 1em; padding: 0px; border: 0px; font-size: 15px; clear: both; color: rgb(34, 34, 34); font-family: 'Helvetica Neue', Helvetica, Arial, sans-serif; font-style: normal; font-variant: normal; font-weight: normal; letter-spacing: normal; line-height: 17.7272720336914px; orphans: auto; text-align: left; text-indent: 0px; text-transform: none; white-space: normal; widows: 1; word-spacing: 0px; -webkit-text-stroke-width: 0px; background-color: rgb(255, 255, 255);"&gt;Active Stalled Idle&lt;/P&gt;

&lt;P style="margin: 0px 0px 1em; padding: 0px; border: 0px; font-size: 15px; clear: both; color: rgb(34, 34, 34); font-family: 'Helvetica Neue', Helvetica, Arial, sans-serif; font-style: normal; font-variant: normal; font-weight: normal; letter-spacing: normal; line-height: 17.7272720336914px; orphans: auto; text-align: left; text-indent: 0px; text-transform: none; white-space: normal; widows: 1; word-spacing: 0px; -webkit-text-stroke-width: 0px; background-color: rgb(255, 255, 255);"&gt;24.6% 18.1% 57.2%&lt;/P&gt;

&lt;P style="margin: 0px 0px 1em; padding: 0px; border: 0px; font-size: 15px; clear: both; color: rgb(34, 34, 34); font-family: 'Helvetica Neue', Helvetica, Arial, sans-serif; font-style: normal; font-variant: normal; font-weight: normal; letter-spacing: normal; line-height: 17.7272720336914px; orphans: auto; text-align: left; text-indent: 0px; text-transform: none; white-space: normal; widows: 1; word-spacing: 0px; -webkit-text-stroke-width: 0px; background-color: rgb(255, 255, 255);"&gt;Also my computing threads started number is &lt;STRONG style="margin: 0px; padding: 0px; border: 0px; font-size: 15px; font-weight: bold;"&gt;24,525,023&lt;/STRONG&gt;, which is quite high.I don't know how to reduce the number of threads started here and result in increased performance.&lt;/P&gt;

&lt;P style="margin: 0px 0px 1em; padding: 0px; border: 0px; font-size: 15px; clear: both; color: rgb(34, 34, 34); font-family: 'Helvetica Neue', Helvetica, Arial, sans-serif; font-style: normal; font-variant: normal; font-weight: normal; letter-spacing: normal; line-height: 17.7272720336914px; orphans: auto; text-align: left; text-indent: 0px; text-transform: none; white-space: normal; widows: 1; word-spacing: 0px; -webkit-text-stroke-width: 0px; background-color: rgb(255, 255, 255);"&gt;I can't understand how to improve its performance. I have gone through this link on optimizations&lt;A href="https://int2-software.intel.com/en-us/articles/optimizing-simple-opencl-kernels" rel="nofollow" style="margin: 0px; padding: 0px; border: 0px; font-size: 15px; text-decoration: none; cursor: pointer; color: rgb(12, 101, 165);"&gt;https://int2-software.intel.com/en-us/articles/optimizing-simple-opencl-kernels&lt;/A&gt;. At this link all the optimizations are related to buffers where we can read 16 elements from memory in one go. But in my case since I am using Texture memory reads or image API's I don't know the way to increase the performance&lt;/P&gt;</description>
      <pubDate>Tue, 21 Jul 2015 12:32:06 GMT</pubDate>
      <guid>https://community.intel.com/t5/OpenCL-for-CPU/Memcpy-performance-using-opencl-kernel/m-p/1019702#M3234</guid>
      <dc:creator>Manish_K_</dc:creator>
      <dc:date>2015-07-21T12:32:06Z</dc:date>
    </item>
    <item>
      <title>Hi Robert Loffe,</title>
      <link>https://community.intel.com/t5/OpenCL-for-CPU/Memcpy-performance-using-opencl-kernel/m-p/1019703#M3235</link>
      <description>&lt;P&gt;Hi Robert Loffe,&lt;/P&gt;

&lt;P&gt;Could you please help here ?&lt;/P&gt;

&lt;P&gt;Thanks!&lt;/P&gt;</description>
      <pubDate>Wed, 22 Jul 2015 04:53:25 GMT</pubDate>
      <guid>https://community.intel.com/t5/OpenCL-for-CPU/Memcpy-performance-using-opencl-kernel/m-p/1019703#M3235</guid>
      <dc:creator>Manish_K_</dc:creator>
      <dc:date>2015-07-22T04:53:25Z</dc:date>
    </item>
    <item>
      <title>Hi Manish,</title>
      <link>https://community.intel.com/t5/OpenCL-for-CPU/Memcpy-performance-using-opencl-kernel/m-p/1019704#M3236</link>
      <description>&lt;P&gt;Hi Manish,&lt;/P&gt;

&lt;P&gt;Sorry for the late reply: I was out of the office yesterday. Could you please let me know the following:&lt;/P&gt;

&lt;P&gt;1. What is your OS?&lt;/P&gt;

&lt;P&gt;2. What is the processor you are working on?&lt;/P&gt;

&lt;P&gt;3. Which version of the graphics driver do you use?&lt;/P&gt;

&lt;P&gt;4. What is the global size for your kernel?&lt;/P&gt;

&lt;P&gt;5. What, if any, is your local size?&lt;/P&gt;

&lt;P&gt;6. What is the version of the Vtune that you are using?&lt;/P&gt;

&lt;P&gt;Also, if it possible to attach a full source code of your sample, please do so.&lt;/P&gt;</description>
      <pubDate>Wed, 22 Jul 2015 16:26:25 GMT</pubDate>
      <guid>https://community.intel.com/t5/OpenCL-for-CPU/Memcpy-performance-using-opencl-kernel/m-p/1019704#M3236</guid>
      <dc:creator>Robert_I_Intel</dc:creator>
      <dc:date>2015-07-22T16:26:25Z</dc:date>
    </item>
    <item>
      <title>Hi Robert,</title>
      <link>https://community.intel.com/t5/OpenCL-for-CPU/Memcpy-performance-using-opencl-kernel/m-p/1019705#M3237</link>
      <description>&lt;P&gt;Hi Robert,&lt;/P&gt;

&lt;P&gt;I am using below configuration and code:&lt;/P&gt;

&lt;P&gt;1. What is your OS?&amp;nbsp; Windows 7 64 bit&lt;/P&gt;

&lt;P&gt;2. What is the processor you are working on?&amp;nbsp; i7 4770 CPU @3.4 GHz&lt;/P&gt;

&lt;P&gt;3. Which version of the graphics driver do you use? 10.18.14.4222&lt;/P&gt;

&lt;P&gt;4. What is the global size for your kernel? 1920x1080&lt;/P&gt;

&lt;P&gt;5. What, if any, is your local size? I have set it to NULL&lt;/P&gt;

&lt;P&gt;6. What is the version of the Vtune that you are using? Vtune 2015 update 2&lt;/P&gt;

&lt;P&gt;Here are the parts of the code which I am using to run this kernel:&lt;/P&gt;

&lt;P&gt;/*Setting the params */&lt;/P&gt;

&lt;P&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp; img_fmt.image_channel_order = CL_R;&lt;BR /&gt;
	&amp;nbsp;&amp;nbsp; &amp;nbsp;img_fmt.image_channel_data_type = CL_UNSIGNED_INT8;&lt;/P&gt;

&lt;P&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp; p-&amp;gt;origin[0] = 0;&amp;nbsp; //width of image&lt;BR /&gt;
	&amp;nbsp;&amp;nbsp;&amp;nbsp; p-&amp;gt;origin[1] = 0;&amp;nbsp; //height of image&lt;BR /&gt;
	&amp;nbsp;&amp;nbsp;&amp;nbsp; p-&amp;gt;origin[2] = 0;&amp;nbsp; //req for 3D image&lt;/P&gt;

&lt;P&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp; p-&amp;gt;region[0] = width;&lt;BR /&gt;
	&amp;nbsp;&amp;nbsp;&amp;nbsp; p-&amp;gt;region[1] = height;&lt;BR /&gt;
	&amp;nbsp;&amp;nbsp;&amp;nbsp; p-&amp;gt;region[2] = 1;&amp;nbsp; // For a 2D image this is set to 1&lt;/P&gt;

&lt;P&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp; p-&amp;gt;global_ws[0][0] = width;&lt;BR /&gt;
	&amp;nbsp;&amp;nbsp;&amp;nbsp; p-&amp;gt;global_ws[0][1] = (height);&lt;/P&gt;

&lt;P&gt;&amp;nbsp; /* ingest frame to global memory on the device: */&amp;nbsp;&amp;nbsp; &amp;nbsp;&lt;BR /&gt;
	&amp;nbsp; ret = clEnqueueWriteImage(p-&amp;gt;command_queue, p-&amp;gt;memobj_in_luma, CL_FALSE, p-&amp;gt;origin, \&lt;BR /&gt;
	&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp; p-&amp;gt;region,0,0,(void *) in,&amp;nbsp; 0, NULL, &amp;amp;evt[0]);&lt;/P&gt;

&lt;P&gt;/*enqueue the kernel*/&lt;BR /&gt;
	&amp;nbsp; ret = clEnqueueNDRangeKernel(p-&amp;gt;command_queue, p-&amp;gt;deint_kernel_y, 2, 0, \&lt;BR /&gt;
	&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp; p-&amp;gt;global_ws[0], NULL, 1, &amp;amp;evt[0], &amp;amp;evt[3]);&lt;/P&gt;

&lt;P&gt;/* Read back from device*/&lt;/P&gt;

&lt;P&gt;&amp;nbsp; ret = clEnqueueReadImage(p-&amp;gt;command_queue, p-&amp;gt;memobj_out_luma, CL_FALSE, \&lt;BR /&gt;
	&amp;nbsp;&amp;nbsp;&amp;nbsp; p-&amp;gt;origin,p-&amp;gt;region,0, 0,(void *)(out),0, 0, 0);&lt;/P&gt;

&lt;P&gt;/* KERNEL CODE */&lt;/P&gt;

&lt;PRE&gt;__kernel void deinterlace_Y(__read_only image2d_t YIn, __write_only image2d_t YOut)
{

/* Doing operation of Memcpy */

int2 coord_src = (int2)(get_global_id(0), get_global_id(1));

const sampler_t smp = CLK_FILTER_NEAREST | CLK_NORMALIZED_COORDS_FALSE | CLK_ADDRESS_CLAMP_TO_EDGE;

uint4 pixel4 = read_imageui(YIn, smp, coord_src);

write_imageui(YOut, coord_src, pixel4);
&lt;/PRE&gt;

&lt;P&gt;}&lt;/P&gt;

&lt;P&gt;&amp;nbsp;&lt;/P&gt;</description>
      <pubDate>Thu, 23 Jul 2015 06:05:09 GMT</pubDate>
      <guid>https://community.intel.com/t5/OpenCL-for-CPU/Memcpy-performance-using-opencl-kernel/m-p/1019705#M3237</guid>
      <dc:creator>Manish_K_</dc:creator>
      <dc:date>2015-07-23T06:05:09Z</dc:date>
    </item>
  </channel>
</rss>

